<?php
include '../includes/db.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Retrieve and sanitize inputs
    $email = filter_var($_POST['email'] ?? '', FILTER_SANITIZE_EMAIL);
    $password = $_POST['password'] ?? '';

    // Validate the inputs
    if (filter_var($email, FILTER_VALIDATE_EMAIL) && !empty($password)) {
        // Prepare and execute the query using prepared statements
        $query = "SELECT * FROM Drops WHERE Email = ?";
        if ($stmt = $connection->prepare($query)) {
            $stmt->bind_param('s', $email);
            $stmt->execute();
            $result = $stmt->get_result();

            if ($result->num_rows > 0) {
                $row = $result->fetch_assoc();
                
                // Verify the password (assuming passwords are hashed in the database)
                if (password_verify($password, $row['Password'])) {
                    echo json_encode(["status" => "success", "message" => "Login successful", "DropsID" => $row['id']]);
                } else {
                    echo json_encode(["status" => "error", "message" => "Invalid email or password"]);
                }
            } else {
                echo json_encode(["status" => "error", "message" => "Invalid email or password"]);
            }

            $stmt->close();
        } else {
            echo json_encode(["status" => "error", "message" => "Database query failed"]);
        }
    } else {
        echo json_encode(["status" => "error", "message" => "Invalid email or password"]);
    }
} else {
    // Handle preflight request for CORS
    if ($_SERVER['REQUEST_METHOD'] == 'OPTIONS') {
        // Send response with CORS headers to handle preflight
        exit(0);
    }

    echo json_encode(["status" => "error", "message" => "Invalid request method"]);
}
?>
