<?php
include '../includes/db.php';

$response = array();
$checkpoint = isset($_GET['checkpoint']) ? htmlspecialchars($_GET['checkpoint']) : '';
$startDate = isset($_GET['startDate']) ? htmlspecialchars($_GET['startDate']) : '';
$endDate = isset($_GET['endDate']) ? htmlspecialchars($_GET['endDate']) : '';

// Initial query
$query = "SELECT * FROM orders WHERE checkpoint = ? AND status NOT IN (0, 1)";
$params = [$checkpoint];
$types = "s";

// Modify query if dates are provided
if (!empty($startDate) && !empty($endDate)) {
    $query .= " AND DATE(created_at) BETWEEN ? AND ?";
    array_push($params, $startDate, $endDate);
    $types .= "ss";
}

// Prepare statement
$stmt = $connection->prepare($query);
if ($stmt) {
    $stmt->bind_param($types, ...$params);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $response['orders'] = array();
        while ($row = $result->fetch_assoc()) {
            array_push($response['orders'], $row);
        }
        $response['success'] = 1;
    } else {
        $response['success'] = 0;
        $response['message'] = "No orders found for checkpoint $checkpoint";
    }
    $stmt->close();
} else {
    $response['success'] = 0;
    $response['message'] = "Database query failed";
}

echo json_encode($response);
$connection->close();
?>
