<?php
require_once '../vendor/autoload.php';
require_once '../includes/db.php';

$phoneNumber = $_POST['phoneNumber'];
$verificationCode = $_POST['verificationCode'];

// Begin a transaction to ensure atomic operations
$connection->begin_transaction();

try {
    // Query to check the verification code
    $stmt = $connection->prepare("SELECT id FROM user_verification_codes WHERE phone_number = ? AND verification_code = ?");
    $stmt->bind_param("ss", $phoneNumber, $verificationCode);
    $stmt->execute();
    $stmt->store_result();

    if ($stmt->num_rows > 0) {
        $stmt->close();

        // Retrieve the user data from UnVerifiedUsers
        $selectStmt = $connection->prepare("SELECT Email, FullName, Password, PhoneNumber FROM UnVerifiedUsers WHERE PhoneNumber = ?");
        $selectStmt->bind_param("s", $phoneNumber);
        $selectStmt->execute();
        $result = $selectStmt->get_result();

        if ($userData = $result->fetch_assoc()) {
            // Insert the user into Users table and get the inserted ID
            $insertStmt = $connection->prepare("INSERT INTO Users (Email, FullName, Password, PhoneNumber) VALUES (?, ?, ?, ?)");
            $insertStmt->bind_param("ssss", $userData['Email'], $userData['FullName'], $userData['Password'], $userData['PhoneNumber']);
            $insertStmt->execute();
            $insertedUserId = $connection->insert_id; // Get the ID of the inserted user
            $insertStmt->close();

            // Delete the user from UnVerifiedUsers
            $deleteStmt = $connection->prepare("DELETE FROM UnVerifiedUsers WHERE PhoneNumber = ?");
            $deleteStmt->bind_param("s", $phoneNumber);
            $deleteStmt->execute();
            $deleteStmt->close();
        }
        $selectStmt->close();

        // Additionally, delete the verification code as it's no longer needed
        $deleteCodeStmt = $connection->prepare("DELETE FROM user_verification_codes WHERE phone_number = ?");
        $deleteCodeStmt->bind_param("s", $phoneNumber);
        $deleteCodeStmt->execute();
        $deleteCodeStmt->close();

        // Commit the transaction
        $connection->commit();

        // Return success response along with user data
        echo json_encode([
            'verified' => true,
            'user' => [
                'email' => $userData['Email'],
                'fullName' => $userData['FullName'],
                'phoneNumber' => $userData['PhoneNumber'],
                'id' => $insertedUserId
            ]
        ]);
    } else {
        // Verification code does not match
        $stmt->close();
        $connection->rollback(); // Rollback the transaction as verification failed
        echo json_encode(['verified' => false, 'message' => 'Verification code does not match.']);
    }
} catch (Exception $e) {
    // An error occurred, handle the exception
    $connection->rollback(); // Ensure to rollback the transaction on error
    echo json_encode(['error' => 'An error occurred during verification: ' . $e->getMessage()]);
}

$connection->close();
?>
