<?php
include "includes/header.php";

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Sanitize and validate email and password
    $email = filter_var($_POST['email'], FILTER_SANITIZE_EMAIL);
    if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        echo "<script>window.location.href = window.location.pathname + '?id=" . intval($_GET['id']) . "&change=invalid_email';</script>";
        exit;
    }

    $password = $_POST['password'];
    if (empty($password) || strlen($password) < 8) {
        echo "<script>window.location.href = window.location.pathname + '?id=" . intval($_GET['id']) . "&change=weak_password';</script>";
        exit;
    }

    // Hash the new password
    $hashedPassword = password_hash($password, PASSWORD_DEFAULT);

    // Use prepared statements to prevent SQL injection
    $query = "UPDATE admins SET password = ? WHERE email = ?";
    if ($stmt = $connection->prepare($query)) {
        $stmt->bind_param("ss", $hashedPassword, $email);
        if ($stmt->execute()) {
            echo "<script>window.location.href = window.location.pathname + '?id=" . intval($_GET['id']) . "&change=success';</script>";
        } else {
            echo "<script>window.location.href = window.location.pathname + '?id=" . intval($_GET['id']) . "&change=failed';</script>";
        }
        $stmt->close();
    } else {
        echo "<script>window.location.href = window.location.pathname + '?id=" . intval($_GET['id']) . "&change=failed';</script>";
    }
}
?>

<body class="hold-transition sidebar-mini layout-fixed">
    <div class="wrapper">

        <?php include "includes/sidebar.php"; ?>

        <main class="page-content">
            <div class="page-breadcrumb d-none d-sm-flex align-items-center mb-3">
                <div class="breadcrumb-title pe-3">Change Password</div>
                <div class="ps-3">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb mb-0 p-0">
                            <li class="breadcrumb-item"><a href="javascript:;"><i class="bx bx-home-alt"></i></a></li>
                            <li class="breadcrumb-item active" aria-current="page">Change Password</li>
                        </ol>
                    </nav>
                </div>
            </div>

            <div class="row">
                <div class="col-lg-12">
                    <div class="card">
                        <div class="card-body">
                            <div class="border p-3 rounded">
                                <h6 class="mb-0 text-uppercase">Change Password</h6>
                                <hr />
                                <div id="message"></div>
                                <form class="row g-3" method="POST">
                                    <?php
                                        $id = intval($_GET['id']);
                                        $query = "SELECT * FROM admins WHERE id=?";
                                        if ($stmt = $connection->prepare($query)) {
                                            $stmt->bind_param("i", $id);
                                            $stmt->execute();
                                            $result = $stmt->get_result();
                                            if ($row = $result->fetch_assoc()) {
                                    ?>
                                    <div>
                                        <label>Email:</label>
                                        <input class="form-control" type="email" name="email" value="<?php echo $row['email']; ?>" readonly>
                                    </div>
                                    <div>
                                        <label>New Password:</label>
                                        <input class="form-control" type="password" name="password" required>
                                    </div>
                                    <div>
                                        <input type="submit" value="Change Password" class="btn btn-primary">
                                    </div>
                                    <?php
                                            }
                                            $stmt->close();
                                        }
                                    ?>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <script>
                window.onload = function () {
                    const params = new URLSearchParams(window.location.search);
                    const change = params.get('change');
                    if (change === 'success') {
                        success_noti('Password changed successfully.');
                    } else if (change === 'failed') {
                        error_noti('Failed to change password.');
                    } else if (change === 'invalid_email') {
                        error_noti('Invalid email address.');
                    } else if (change === 'weak_password') {
                        error_noti('Password must be at least 8 characters long.');
                    }
                };
            </script>

            <?php include "includes/footer.php"; ?>
</body>
</html>
