<?php include "includes/header.php"; ?>
<?php 
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Sanitize and validate inputs
    $title = htmlspecialchars($_POST['title']);
    $icon = htmlspecialchars($_POST['icon']);
    $link = filter_var($_POST['link'], FILTER_SANITIZE_URL);
    $parent_id = $_POST['parent_id'] === 'NULL' ? NULL : intval($_POST['parent_id']);
    
    // Insert the new sidebar item into the database using prepared statements
    $sidebar_table_name = "sidebar";
    $query = "INSERT INTO $sidebar_table_name (title, link, icon, parent_id) VALUES (?, ?, ?, ?)";
    
    if ($stmt = $connection->prepare($query)) {
        // Bind four parameters, ensuring parent_id is correct
        $stmt->bind_param("sssi", $title, $link, $icon, $parent_id);
        $stmt->execute();
        $stmt->close();
    } else {
        echo "Error: " . $connection->error;
    }
}
?>
<?php include "includes/sidebar.php"; ?>

<main class="page-content">
  <div class="page-breadcrumb d-none d-sm-flex align-items-center mb-3">
    <div class="breadcrumb-title pe-3">Header</div>
    <div class="ps-3">
      <nav aria-label="breadcrumb">
        <ol class="breadcrumb mb-0 p-0">
          <li class="breadcrumb-item"><a href="javascript:;"><i class="bx bx-home-alt"></i></a></li>
          <li class="breadcrumb-item active" aria-current="page">Contact Info</li>
        </ol>
      </nav>
    </div>
  </div>

  <div class="row">
    <div class="col-xl-12">
      <div class="card">
        <div class="card-body">
          <div class="border p-3 rounded">
            <h6 class="mb-0 text-uppercase">Contact Info</h6>
            <hr />
            <form class="row g-3" action="pageCreator.php" method="POST">
              <div class="col-lg-4">
                <input class="form-control" type="text" name="title" placeholder="Item Name" required>
              </div>
              <div class="col-lg-4">
                <input class="form-control" value="bi bi-circle" type="text" name="icon" placeholder="Item Icon" required>
              </div>
              <div class="col-lg-4">
                <input class="form-control" type="text" name="link" placeholder="Item Link" required>
              </div>
              <div class="col-12">
                <label for="parent">Parent:</label>
                <select class="form-control" name="parent_id" id="parent_id">
                  <option value="NULL">NULL</option>
                  <!-- Populate the select options with existing parent items from the database -->
                  <?php
                    $sql = "SELECT * FROM sidebar WHERE parent_id IS NULL ORDER BY id ASC";
                    if ($stmt = $connection->prepare($sql)) {
                        $stmt->execute();
                        $result = $stmt->get_result();
                        while ($row = $result->fetch_assoc()) {
                            echo '<option value="' . htmlspecialchars($row['id']) . '">' . htmlspecialchars($row['title']) . '</option>';
                        }
                        $stmt->close();
                    }
                  ?>
                </select>
              </div>
              <div class="d-grid">
                <button class="btn btn-primary" type="submit">Create Item</button>
              </div>
            </form>
          </div>
        </div>
      </div>
    </div>
  </div>
</main>

<?php include "includes/switcher.php"; ?>
<?php include "includes/footer.php"; ?>
