<?php
include "includes/header.php";

function printPrivileges($tree, $existingPrivileges, $isParent = true){
    foreach ($tree as $i => $item) {
        echo '<div class="row align-items-center">';
        
        echo '<div class="col-lg-8 d-flex align-items-center" style="gap: 1rem;">';
        if(isset($item['submenu']) && count($item['submenu']) > 0){
            echo '<a data-bs-toggle="collapse" href="#collapse'.$item['id'].'" role="button" aria-expanded="false" aria-controls="collapse'.$item['id'].'"><i class="lni lni-chevron-down"></i></a>';
        }
        else{
            echo '<span style="width: 1rem;"></span>';  // To maintain layout alignment
        }
        if($isParent) {
            echo '<h6>'.$item['title'].'</h6>';
        } else {
            echo '<span>'.$item['title'].'</span>';
        }
        echo '</div>';
        
        $isChecked = in_array(strtolower(str_replace(' ', '', $item['title'])), $existingPrivileges) ? 'checked' : '';
        echo '<div class="col-lg-4">';
        $class = $isParent ? 'parent' : 'child';
        echo '<input class="form-check-input ' . $class . '" type="checkbox" value="" id="check'.$item['id'].'" data-name="'.strtolower(str_replace(' ', '', $item['title'])).'" ' . $isChecked . '>';

        echo '</div>';

        echo '</div>';

        if(isset($item['submenu']) && count($item['submenu']) > 0){
            echo '<div class="collapse ml-3" id="collapse'.$item['id'].'">';
            printPrivileges($item['submenu'], $existingPrivileges, false);
            echo '</div>';
        }
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['save'])) {
        $id = intval($_GET['id']);
        $privileges = htmlspecialchars($_POST['privileges']);

        $updateQuery = "UPDATE admins SET privileges = ? WHERE id = ?";
        if ($stmt = $connection->prepare($updateQuery)) {
            $stmt->bind_param("si", $privileges, $id);
            if ($stmt->execute()) {
                echo "<script>window.location.href = window.location.pathname + '?id=$id&update=success';</script>";
            } else {
                echo "<script>window.location.href = window.location.pathname + '?id=$id&update=failure';</script>";
            }
            $stmt->close();
        } else {
            echo "<script>window.location.href = window.location.pathname + '?id=$id&update=failure';</script>";
        }
    }
}

$id = intval($_GET['id']);

// Fetch the current privileges of the admin
$query = "SELECT privileges FROM admins WHERE id=?";
if ($stmt = $connection->prepare($query)) {
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $result = $stmt->get_result();
    $row = $result->fetch_assoc();
    $existingPrivileges = explode(' ', $row['privileges']);
    $stmt->close();
} else {
    $existingPrivileges = [];
}
?>

<body class="hold-transition sidebar-mini layout-fixed">
    <div class="wrapper">
        <?php include "includes/sidebar.php"; ?>
        <main class="page-content">
            <div class="page-breadcrumb d-none d-sm-flex align-items-center mb-3">
                <div class="breadcrumb-title pe-3">Admin Privileges</div>
                <div class="ps-3">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb mb-0 p-0">
                            <li class="breadcrumb-item"><a href="javascript:;"><i class="bx bx-home-alt"></i></a></li>
                            <li class="breadcrumb-item active" aria-current="page">Manage Admin Privileges</li>
                        </ol>
                    </nav>
                </div>
            </div>

            <div class="row">
                <div class="col-lg-8">
                    <div class="card">
                        <div class="card-body">
                            <div class="border p-3 rounded">
                                <h5 class="mb-0 text-uppercase">Admin Privileges</h5>
                                <hr />
                                <form method="post" action="" id="privilegesForm">
                                    <?php printPrivileges($tree, $existingPrivileges); ?>
                                    <input type="hidden" name="privileges" id="privileges">
                                    <div class="d-flex justify-content-end mt-3">
                                        <button type="submit" name="save" class="btn btn-primary">Save</button>
                                    </div>
                                </form>

                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-lg-4">
                    <div class="card shadow-sm border-0 overflow-hidden">
                        <div class="card-body">
                            <div class="profile-avatar text-center">
                                <?php
                                    $query = "SELECT * FROM admins WHERE id=?";
                                    if ($stmt = $connection->prepare($query)) {
                                        $stmt->bind_param("i", $id);
                                        $stmt->execute();
                                        $result = $stmt->get_result();
                                        $row = $result->fetch_assoc();
                                        $stmt->close();
                                    }
                                ?>
                                <?php if (!empty($row['image'])): ?>
                                <img src="<?php echo htmlspecialchars($row['image']); ?>" class="rounded-circle shadow" width="120" height="120" alt="Profile Image">
                                <?php else: ?>
                                <img src="assets/images/avatars/avatar-1.png" class="rounded-circle shadow" width="120" height="120" alt="Default Profile Image">
                                <?php endif; ?>
                            </div>
                            <div class="text-center mt-4">
                                <h4 class="mb-1"><?php echo htmlspecialchars($row['firstName'] . ' ' . $row['lastName']); ?></h4>
                                <p class="mb-0 text-secondary">
                                    <?php echo htmlspecialchars($row['city'] . ', ' . $row['country'] . ' / ' . $row['phoneNumber']); ?>
                                </p>
                                <div class="mt-4"></div>
                                <h6 class="mb-1"><?php echo htmlspecialchars($row['role']); ?></h6>
                                <p class="mb-0 text-secondary"><?php echo htmlspecialchars($row['university']); ?></p>
                            </div>
                            <hr>
                            <div class="text-start">
                                <h5 class="">About</h5>
                                <p class="mb-0"><?php echo htmlspecialchars($row['aboutMe']); ?></p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </main>
    </div>

    <!-- Place this at the end of the HTML body -->
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script src="assets/plugins/notifications/js/notifications1.js"></script>
    <script>
        window.onload = function () {
            const params = new URLSearchParams(window.location.search);
            const update = params.get('update');

            if (update === 'success') {
                success_noti('Admin Privileges updated successfully.');
            } else if (update === 'failure') {
                error_noti('Failed to update Admin Privileges.');
            } else if (update === 'failed') {
                error_noti('An error occurred while uploading the image.');
            }
        };

        $(document).ready(function () {
            $('input[type="checkbox"]').click(function () {
                // If it's a parent and is being checked, check all its children
                // If it's a parent and is being unchecked, uncheck all its children
                if ($(this).hasClass('parent')) {
                    $(this).closest('.row').next('.collapse').find('input[type="checkbox"]')
                        .prop('checked', $(this).prop('checked'));
                }
                // If it's a child and is being checked, check its parent
                // No action needed when a child is unchecked
                else if ($(this).hasClass('child') && $(this).prop('checked')) {
                    $(this).closest('.collapse').prev('.row').find('input.parent').prop('checked',
                        true);
                }
            });
            $('input[type="checkbox"]').on('change', function () {
                const privileges = [];
                $('.form-check-input').each(function () {
                    if (this.checked) {
                        privileges.push($(this).data('name'));
                    }
                });
                $('#privileges').val(privileges.join(' '));
            });
        });
    </script>

<?php include "includes/footer.php"; ?>
