<?php
include "includes/db.php";

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $email = filter_var($_POST['email'], FILTER_SANITIZE_EMAIL);
    $password = $_POST['password'];

    // Validate email
    if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $response = array('success' => false, 'message' => 'Invalid email format.');
        echo json_encode($response);
        exit();
    }

    // Check if the user exists using prepared statements
    $query = "SELECT * FROM admins WHERE email = ?";
    if ($stmt = $connection->prepare($query)) {
        $stmt->bind_param("s", $email);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            $row = $result->fetch_assoc();
            $hashedPassword = $row['password'];

            // Verify the password
            if (password_verify($password, $hashedPassword)) {
                // Password is correct, sign in the user
                session_start();
                $_SESSION['admin_email'] = $email;
                $_SESSION['admin_id'] = $row['id']; // Store the ID in the session
                $response = array('success' => true, 'message' => 'Sign in successful.');
            } else {
                // Password is incorrect
                $response = array('success' => false, 'message' => 'Invalid password.');
            }
        } else {
            // User does not exist
            $response = array('success' => false, 'message' => 'Invalid email.');
        }

        $stmt->close();
    } else {
        $response = array('success' => false, 'message' => 'Database query failed.');
    }

    // Send JSON response
    header('Content-Type: application/json');
    echo json_encode($response);
    exit();
}
?>
